FreeLine class

Inheritance

Constructors

FreeLine(List<Offset> path, Color color, double strokeWidth, StrokeCap strokeCap)

Properties

color Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
path List<Offset>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeCap StrokeCap
getter/setter pair
strokeWidth double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited